@@ -1,6 +1,11 @@
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
+
 import os
 import platform
 import socket
+from abc import ABCMeta, abstractmethod
 
 from ..wptcommandline import require_arg
 
@@ -42,6 +47,8 @@ class BrowserError(Exception):
 
 
 class Browser(object):
+    __metaclass__ = ABCMeta
+
     process_cls = None
     init_timeout = 30
 
@@ -68,21 +75,25 @@ class Browser(object):
         """Used for browser-specific setup that happens at the start of a test run"""
         pass
 
+    @abstractmethod
     def start(self):
         """Launch the browser object and get it into a state where is is ready to run tests"""
-        raise NotImplementedError
+        pass
 
-    def stop():
+    @abstractmethod
+    def stop(self):
         """Stop the running browser process."""
-        raise NotImplementedError
+        pass
 
+    @abstractmethod
     def on_output(self, line):
         """Callback function used with ProcessHandler to handle output from the browser process."""
-        raise NotImplementedError
+        pass
 
+    @abstractmethod
     def is_alive(self):
         """Boolean indicating whether the browser process is still running"""
-        raise NotImplementedError
+        pass
 
     def cleanup(self):
         """Browser-specific cleanup that is run after the testrun is finished"""
@@ -107,6 +118,8 @@ class NullBrowser(Browser):
     def is_alive(self):
         return True
 
+    def on_output(self, line):
+        raise NotImplementedError
 
 class ExecutorBrowser(object):
     def __init__(self, **kwargs):
