@@ -1,3 +1,7 @@
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
+
 import sys
 import tempfile
 from cStringIO import StringIO
@@ -44,8 +48,6 @@ class Reducer(object):
     def __init__(self, target, **kwargs):
         self.target = target
 
-        print kwargs
-
         self.test_type = kwargs["test_types"][0]
         run_info = wpttest.get_run_info(kwargs["product"], debug=False)
         test_filter = wptrunner.TestFilter(include=kwargs["include"])
@@ -136,8 +138,8 @@ class Reducer(object):
 
             sys.stdout, sys.stderr = stdout, stderr
 
-        logger.debug("Result %s unstable with chunk removed" %
-                     ("was" if is_unstable else "was not"))
+        logger.debug("Result was unstable with chunk removed"
+                     if is_unstable else "stable")
 
         return is_unstable
 
