@@ -28,11 +28,6 @@ from testrunner import ManagerGroup
 here = os.path.split(__file__)[0]
 
 
-# TODO
-# Multiplatform expectations
-# Documentation
-# HTTP server crashes
-
 """Runner for web-platform-tests
 
 The runner has several design goals:
@@ -140,6 +135,7 @@ class TestEnvironment(object):
                 shutil.copy2(source_path, dest_path)
 
     def ensure_started(self):
+        # Pause for a while to ensure that the server has a chance to start
         time.sleep(2)
         for scheme, servers in self.servers.iteritems():
             for port, server in servers:
@@ -265,15 +261,15 @@ class EqualTimeChunker(TestChunker):
 
             def add_path(self, path_data):
                 sum_time = self.current_chunk.time + path_data.time
-                if sum_time > self.time_per_chunk:
+                if sum_time > self.time_per_chunk and self.remaining_chunks > 0:
                     overshoot = sum_time - self.time_per_chunk
                     undershoot = self.time_per_chunk - self.current_chunk.time
                     if overshoot < undershoot:
                         self.create()
                         self.current_chunk.append(path_data)
                     else:
-                        self.create()
                         self.current_chunk.append(path_data)
+                        self.create()
                 else:
                     self.current_chunk.append(path_data)
 
@@ -466,9 +462,7 @@ class LogThread(threading.Thread):
         while True:
             try:
                 msg = self.queue.get()
-            except EOFError:
-                break
-            except IOError:
+            except (EOFError, IOError):
                 break
             if msg is None:
                 break
@@ -525,7 +519,7 @@ def list_disabled(tests_root, metadata_root, test_types, product, **kwargs):
     print json.dumps(rv, indent=2)
 
 
-def run_tests(tests_root, metadata_root, product, **kwargs):
+def run_tests(config, tests_root, metadata_root, product, **kwargs):
     logging_queue = None
     logging_thread = None
     original_stdio = (sys.stdout, sys.stderr)
@@ -546,7 +540,7 @@ def run_tests(tests_root, metadata_root, product, **kwargs):
         (check_args,
          browser_cls, get_browser_kwargs,
          executor_classes, get_executor_kwargs,
-         env_options) = products.load_product(product)
+         env_options) = products.load_product(config, product)
 
         check_args(**kwargs)
 
